@@ -464,6 +464,15 @@ sub _end_channel {
     shift->_end_top_level_elem("channel");
 }
 
+sub _output_array_item_tag {
+    my ($self, $item, $tag) = @_;
+
+    if (defined($item->{$tag})) {
+        $self->_out_array_tag($tag, $item->{$tag});
+    }
+
+    return;
+}
 
 sub _output_def_item_tag {
     my ($self, $item, $tag) = @_;
@@ -541,13 +550,29 @@ sub _prefer_dc {
     return $self->{_prefer_dc};
 }
 
+sub _calc_channel_dc_field_params {
+    my ($self, $dc_key, $non_dc_key) = @_;
+
+    return
+    (
+        $self->_prefer_dc() ? "dc:$dc_key" : $non_dc_key,
+        $self->_calc_channel_dc_field($dc_key, $non_dc_key)
+    );
+}
 
 sub _out_channel_dc_field {
     my ($self, $dc_key, $non_dc_key) = @_;
 
     return $self->_out_defined_tag(
-        ($self->_prefer_dc() ? "dc:$dc_key" : $non_dc_key),
-        $self->_calc_channel_dc_field($dc_key, $non_dc_key)
+        $self->_calc_channel_dc_field_params($dc_key, $non_dc_key),
+    );
+}
+
+sub _out_channel_array_self_dc_field {
+    my ($self, $key) = @_;
+
+    $self->_out_array_tag(
+        $self->_calc_channel_dc_field_params($key, $key),
     );
 }
 
@@ -743,7 +768,7 @@ sub _out_complete_outer_tag {
 
     if (defined($value)) {
         $self->_out("<$outer>\n");
-        $self->_out_tag($inner, $value);
+        $self->_out_array_tag($inner, $value);
         $self->_end_top_level_elem($outer);
     }
 }
@@ -846,7 +871,7 @@ sub _get_rdf_decl_mappings
     return
     [
         $self->_get_first_rdf_decl_mappings(),
-        map { [$modules->{$_}, $_] } keys(%$modules)
+        sort { $a->[0] cmp $b->[0] } map { [$modules->{$_}, $_] } keys(%$modules)
     ];
 }
 
@@ -909,7 +934,7 @@ sub _out_guid {
 
 sub _out_item_source {
     my ($self, $item) = @_;
-    
+
     if (defined $item->{source} && defined $item->{sourceUrl}) {
         $self->_out('<source url="'
           . $self->_encode($item->{sourceUrl}) . '">'
@@ -918,17 +943,29 @@ sub _out_item_source {
     }
 }
 
-sub _out_item_enclosure {
-    my ($self, $item) = @_;
+sub _out_single_item_enclosure {
+    my ($self, $item, $enc) = @_;
 
-    if (my $e = $item->{enclosure}) {
+    return
         $self->_out(
             "<enclosure " .
-            join(' ', 
-                map { "$_=\"" . $self->_encode($e->{$_}) . '"' } keys(%$e)
+            join(' ',
+                map { "$_=\"" . $self->_encode($enc->{$_}) . '"' } keys(%$enc)
             ) .
             " />\n"
         );
+}
+
+sub _out_item_enclosure {
+    my ($self, $item) = @_;
+
+    if (my $enc = $item->{enclosure}) {
+        foreach my $sub (
+            (ref($enc) eq "ARRAY") ? @$enc : ($enc)
+        )
+        {
+            $self->_out_single_item_enclosure($item, $sub)
+        }
     }
 }
 
